@@ -18,7 +18,7 @@ import org.gcube.common.homelibrary.home.workspace.folder.FolderItem;
 import org.gcube.common.homelibrary.home.workspace.folder.items.GCubeItem;
 import org.gcube.datacatalogue.ckanutillibrary.server.utils.UtilMethods;
 import org.gcube.datacatalogue.ckanutillibrary.shared.ResourceBean;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.DatasetMetadataBean;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.DatasetBean;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.ResourceElementBean;
 
 import com.liferay.portal.kernel.log.Log;
@@ -26,85 +26,10 @@ import com.liferay.portal.kernel.log.LogFactoryUtil;
 
 public class WorkspaceUtils {
 
-
 	//private static final org.slf4j.Logger logger = LoggerFactory.getLogger(WorkspaceUtils.class);
 	private static final Log logger = LogFactoryUtil.getLog(WorkspaceUtils.class);
 	private static final String RESOURCES_NAME_SEPARATOR = "_";
-
-	/**
-	 * Copy into the .catalogue area folder the checked resources.
-	 * There is no difference among a single-file-publish and a folder-publish.
-	 * @param folderId
-	 * @param userName
-	 * @param bean
-	 * @return
-	 */
-	public static List<ResourceBean> copyResourcesToUserCatalogueArea(String folderOrFileId, String userName, DatasetMetadataBean bean) throws Exception{
-
-		logger.debug("Request to copy onto catalogue area....");
-		List<ResourceBean> resources = new ArrayList<ResourceBean>();
-		WorkspaceItem copiedFolder = null;
-		WorkspaceCatalogue userCatalogue = null;
-		ResourceElementBean rootResource = bean.getResourceRoot();
-
-		// into the .catalogue area of the user's workspace
-		Workspace ws = HomeLibrary
-				.getHomeManagerFactory()
-				.getHomeManager()
-				.getHome()
-				.getWorkspace();
-
-		// Retrieve the catalogue of the user
-		userCatalogue = ws.getCatalogue();
-
-		// get workspace item (it could be a file or a folder)
-		WorkspaceItem originalItem = ws.getItem(folderOrFileId);
-
-		// copy the folder in the catalogue if it is a folder, or create a new folder
-		long referenceTime = System.currentTimeMillis();
-		if(originalItem.isFolder()){
-			copiedFolder = userCatalogue.addWorkspaceItem(folderOrFileId, userCatalogue.getId()); // add to .catalogue root area
-			copiedFolder.setDescription(bean.getDescription());
-		}
-		else{
-			copiedFolder = userCatalogue.createFolder(UtilMethods.fromProductTitleToName(bean.getTitle()) + "_" + referenceTime, bean.getDescription());
-		}
-
-		// change name of the copied folder to match the title (append the timestamp to avoid ties)
-		((WorkspaceFolder)copiedFolder).rename(UtilMethods.fromProductTitleToName(bean.getTitle()) + "_" + referenceTime);
-
-		// retrieve the children
-		List<ResourceElementBean> resourcesToAdd = rootResource.getChildren();
-
-		// copy only the selected ones
-		for(ResourceElementBean resource : resourcesToAdd){
-
-			if (resource.isToBeAdded()) {
-
-				logger.debug("Resource to add is " + resource);
-
-				// ok it is a file, so copy it into the copiedFolder
-				WorkspaceItem copiedFile = userCatalogue.addWorkspaceItem(resource.getOriginalIdInWorkspace(), copiedFolder.getId());
-
-				// name and description could have been edited
-				copiedFile.setDescription(resource.getDescription());
-
-				resources.add(new ResourceBean(
-						copiedFile.getPublicLink(true), 
-						resource.getName(), 
-						copiedFile.getDescription(), 
-						copiedFile.getId(),
-						userName, 
-						null, // dataset id, to be set
-						((FolderItem)copiedFile).getMimeType()));
-
-				// postpone rename operation
-				copiedFile.rename(resource.getName() + "_" + referenceTime);
-			}
-
-		}
-		return resources;
-	}
+	private static final String STRIP_NOT_ALPHANUMERIC = "[^A-Za-z0-9.-_]";
 
 	/**
 	 * This method receives a folder id within the user's workspace and set the list of resources in the dataset bean to be returned
@@ -115,7 +40,7 @@ public class WorkspaceUtils {
 	 * @throws Exception
 	 */
 	public static void handleWorkspaceResources(String folderId, String userName,
-			DatasetMetadataBean bean) throws Exception {
+			DatasetBean bean) throws Exception {
 
 		// get workspace
 		Workspace ws = HomeLibrary
@@ -124,7 +49,7 @@ public class WorkspaceUtils {
 				.getHome().getWorkspace();
 
 		WorkspaceItem originalFolderOrFile = ws.getItem(folderId);
-		
+
 		logger.debug("Item retrieved is " + originalFolderOrFile);
 
 		if(!originalFolderOrFile.isFolder()){
@@ -136,12 +61,12 @@ public class WorkspaceUtils {
 			resource.setName(originalFolderOrFile.getName());
 			resource.setOriginalIdInWorkspace(folderId);
 			bean.setResourceRoot(resource);
-			bean.setTitle(originalFolderOrFile.getName().replaceAll("[^A-Za-z0-9.-_]", " "));
+			bean.setTitle(originalFolderOrFile.getName().replaceAll(STRIP_NOT_ALPHANUMERIC, " "));
 			bean.setDescription(originalFolderOrFile.getDescription());
 
 		}else{
 
-			String onlyAlphanumericTitle = originalFolderOrFile.getName().replaceAll("[^A-Za-z0-9.-_]", " "); // that is, remove characters different than the ones inside
+			String onlyAlphanumericTitle = originalFolderOrFile.getName().replaceAll(STRIP_NOT_ALPHANUMERIC, " "); 
 			bean.setTitle(onlyAlphanumericTitle);
 			bean.setDescription(originalFolderOrFile.getDescription());
 
@@ -166,7 +91,7 @@ public class WorkspaceUtils {
 		}
 
 	}
-	
+
 	/** Gets the gcube item properties.
 	 *
 	 * @param item the item
@@ -200,28 +125,23 @@ public class WorkspaceUtils {
 	 * @throws Exception 
 	 */
 	public static ResourceElementBean getTreeFromFolder(String workspaceFolderId, Workspace ws) throws Exception{
+
 		ResourceElementBean rootElem = new ResourceElementBean();
 		String pathSeparator = ws.getPathSeparator();
-		try{
-			WorkspaceItem initialItem = ws.getItem(workspaceFolderId);
-			String fullPathBase = initialItem.getPath();
-			fullPathBase = fullPathBase.endsWith(ws.getPathSeparator()) ? fullPathBase : fullPathBase + ws.getPathSeparator();
-			rootElem.setFolder(initialItem.isFolder());
-			rootElem.setFullPath(initialItem.getPath().replace(fullPathBase, ""));
-			rootElem.setParent(null);
-			rootElem.setName(initialItem.getName());
-			rootElem.setOriginalIdInWorkspace(initialItem.getId());
-			rootElem.setDescription(initialItem.getDescription());
-			extractEditableNameFromPath(rootElem, pathSeparator);
+		WorkspaceItem initialItem = ws.getItem(workspaceFolderId);
+		String fullPathBase = initialItem.getPath();
+		fullPathBase = fullPathBase.endsWith(ws.getPathSeparator()) ? fullPathBase : fullPathBase + ws.getPathSeparator();
+		rootElem.setFolder(initialItem.isFolder());
+		rootElem.setFullPath(initialItem.getPath().replace(fullPathBase, ""));
+		rootElem.setName(initialItem.getName());
+		rootElem.setOriginalIdInWorkspace(initialItem.getId());
+		rootElem.setDescription(initialItem.getDescription());
+		extractEditableNameFromPath(rootElem, pathSeparator);
+
+		// recursive visiting
+		if(initialItem.isFolder())
+			visit(rootElem, initialItem, fullPathBase, pathSeparator);
 
-			// recursive visiting
-			if(initialItem.isFolder())
-				visit(rootElem, initialItem, fullPathBase, pathSeparator);
-		}catch(Exception e){
-			logger.error("Failed to build the resource tree", e);
-			return null;
-		}
-		
 		logger.debug("Tree that is going to be returned is " + rootElem);
 		return rootElem;
 	}
@@ -236,6 +156,10 @@ public class WorkspaceUtils {
 		List<? extends WorkspaceItem> children = initialItemWS.getChildren();
 		ArrayList<ResourceElementBean> childrenInTree = new ArrayList<ResourceElementBean>(children.size());
 		for (WorkspaceItem item : children) {
+			//			logger.debug("Path BEFORE REPLACE is " + item.getPath());
+			//			logger.debug("Path AFTER REPLACE is " + item.getPath().replace(fullPathBase, ""));
+			//			logger.debug("Name is " + item.getName());
+			//			logger.debug("id is " + item.getId());
 			ResourceElementBean elem = new ResourceElementBean();
 			elem.setFolder(item.isFolder());
 			elem.setOriginalIdInWorkspace(item.getId());
@@ -264,10 +188,101 @@ public class WorkspaceUtils {
 			return;
 
 		String elemName = rootElem.getName();
+		String fullPath = rootElem.getFullPath();
+		logger.info("Element original is " + rootElem);
+
 		int lastIndex = rootElem.getFullPath().lastIndexOf(elemName);
-		String fullPath = rootElem.getFullPath().substring(0, lastIndex);
+		fullPath = rootElem.getFullPath().substring(0, lastIndex);
 		fullPath = fullPath.replaceAll(pathSeparatorInWs, RESOURCES_NAME_SEPARATOR) + elemName;
 		rootElem.setEditableName(fullPath);
 	}
 
+	/**
+	 * Copy into the .catalogue area folder the checked resources.
+	 * There is no difference among a single-file-publish and a folder-publish.
+	 * @param folderId
+	 * @param userName
+	 * @param bean
+	 * @return
+	 */
+	public static List<ResourceBean> copyResourcesToUserCatalogueArea(String folderOrFileId, String userName, DatasetBean bean) throws Exception{
+
+		logger.debug("Request to copy onto catalogue area....");
+		List<ResourceBean> resources = new ArrayList<ResourceBean>();
+		WorkspaceItem copiedFolder = null;
+		WorkspaceCatalogue userCatalogue = null;
+		ResourceElementBean rootResource = bean.getResourceRoot();
+
+		// into the .catalogue area of the user's workspace
+		Workspace ws = HomeLibrary
+				.getHomeManagerFactory()
+				.getHomeManager()
+				.getHome()
+				.getWorkspace();
+
+		// Retrieve the catalogue of the user
+		userCatalogue = ws.getCatalogue();
+
+		// get workspace item (it could be a file or a folder)
+		WorkspaceItem originalItem = ws.getItem(folderOrFileId);
+
+		// copy the folder in the catalogue if it is a folder, or create a new folder
+		long referenceTime = System.currentTimeMillis();
+		if(originalItem.isFolder()){
+			copiedFolder = userCatalogue.addWorkspaceItem(folderOrFileId, userCatalogue.getId()); // add to .catalogue root area
+			copiedFolder.setDescription(bean.getDescription());
+			((WorkspaceFolder)copiedFolder).rename(UtilMethods.fromProductTitleToName(bean.getTitle()) + "_" + referenceTime);
+		}
+		else{
+			copiedFolder = userCatalogue.createFolder(UtilMethods.fromProductTitleToName(bean.getTitle()) + "_" + referenceTime, bean.getDescription());
+		}
+
+		// retrieve the children
+		List<ResourceElementBean> resourcesToAdd = rootResource.getChildren();
+
+		// copy only the selected ones
+		for(ResourceElementBean resource : resourcesToAdd){
+
+			if (resource.isToBeAdded()) {
+
+				logger.debug("Resource to add is " + resource);
+
+				// ok it is a file, so copy it into the copiedFolder
+				WorkspaceItem copiedFile = userCatalogue.addWorkspaceItem(resource.getOriginalIdInWorkspace(), copiedFolder.getId());
+
+				// name and description could have been edited
+				copiedFile.setDescription(resource.getDescription());
+
+				resources.add(new ResourceBean(
+						copiedFile.getPublicLink(true), 
+						resource.getEditableName(), 
+						copiedFile.getDescription(), 
+						copiedFile.getId(),
+						userName, 
+						null, // dataset id, to be set
+						((FolderItem)copiedFile).getMimeType()));
+
+				// postpone rename operation
+				copiedFile.rename(resource.getEditableName());
+			}
+
+		}
+		return resources;
+	}
+
+	//	public static void main(String[] args) throws Exception {
+	//
+	//		ScopeProvider.instance.set();
+	//		SecurityTokenProvider.instance.set();
+	//		String path = "/Workspace/DataMiner";
+	//		Workspace ws = HomeLibrary
+	//				.getHomeManagerFactory()
+	//				.getHomeManager()
+	//				.getHome()
+	//				.getWorkspace();
+	//		WorkspaceItem miner = ws.getItemByPath(path);
+	//		handleWorkspaceResources(miner.getId(), "costantino.perciante", new DatasetBean());
+	//
+	//	}
+
 }
\ No newline at end of file
